var hostcheckercontroller_8h =
[
    [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", "classSteinberg_1_1Vst_1_1HostCheckerController" ],
    [ "ScoreEntry", "structSteinberg_1_1Vst_1_1HostCheckerController_1_1ScoreEntry.html", "structSteinberg_1_1Vst_1_1HostCheckerController_1_1ScoreEntry" ],
    [ "kMaxLatencyInSeconds", "namespaceSteinberg_1_1HostChecker.html#a475b7b89c7a9ef6b0f0590fa64e3ec0b", null ],
    [ "kParamWarnCount", "namespaceSteinberg_1_1HostChecker.html#a82a59297717d21868266e8a4fd1da4f0", null ],
    [ "kParamWarnBitCount", "namespaceSteinberg_1_1HostChecker.html#a72e8435dc9b0315802adde434a4fcd14", null ],
    [ "kParamWarnStepCount", "namespaceSteinberg_1_1HostChecker.html#a4bc22a30a6391416bcaa23b915d31916", null ],
    [ "kParamUnitStruct1Count", "namespaceSteinberg_1_1HostChecker.html#ad4383350836de663faf25e58dc9b6529", null ],
    [ "kParamUnitStruct2Count", "namespaceSteinberg_1_1HostChecker.html#a097fa93de17b33e8238e948e44f01527", null ],
    [ "kParamUnitStruct3Count", "namespaceSteinberg_1_1HostChecker.html#a378cad607bca2ff3c5374cc956760452", null ],
    [ "kParamUnitStructCount", "namespaceSteinberg_1_1HostChecker.html#a84a49c10ae740d6cf7b295f653712274", null ]
];